@@ -18,4 +18,7 @@ else:
 		
 
 with open(path,'w') as f:
-	f.write(the_token)
\ No newline at end of file
+	f.write(the_token)
+	
+print('\nYAY! Your token has now been stored under the following path:')
+print(path)
\ No newline at end of file
